==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.dwarfdump/src/org/netbeans/modules/cnd/dwarfdump/trace/TraceDwarf.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.cnd.dwarfdump.trace;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.logging.Level;
import org.netbeans.modules.cnd.dwarfdump.CompilationUnitInterface;
import org.netbeans.modules.cnd.dwarfdump.Dwarf;
import org.netbeans.modules.cnd.dwarfdump.Dwarf.CompilationUnitIterator;
import org.netbeans.modules.cnd.dwarfdump.exception.WrongFileFormatException;


/**
 *
 * @author Sergey Grinev
 */
public class TraceDwarf {
    
    private TraceDwarf() {
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        String objFileName = args[0];
        Dwarf dump = null;
        try {
            Dwarf.LOG.log(Level.FINE, "TraceDwarf.");  // NOI18N
            dump = new Dwarf(objFileName);
            CompilationUnitIterator units = dump.iteratorCompilationUnits();
            int idx = 0;
            if (units != null && units.hasNext()) {
                Dwarf.LOG.log(Level.FINE, "\n**** Done. Compilation units were found"); // NOI18N
                while(units.hasNext()) {
                    CompilationUnitInterface compilationUnit = units.next();
                    Dwarf.LOG.log(Level.FINE, "{0}: {1}", new Object[]{++idx, compilationUnit.getSourceFileName()});// NOI18N
                }

            }
        } catch (FileNotFoundException ex) {
            // Skip Exception
            Dwarf.LOG.log(Level.FINE, "File not found {0}: {1}", new Object[]{objFileName, ex.getMessage()});  // NOI18N
        } catch (WrongFileFormatException ex) {
            Dwarf.LOG.log(Level.FINE, "Unsuported format of file {0}: {1}", new Object[]{objFileName, ex.getMessage()});  // NOI18N
        } catch (IOException ex) {
            Dwarf.LOG.log(Level.FINE, "Exception in file " + objFileName, ex);  // NOI18N
        } catch (Exception ex) {
            Dwarf.LOG.log(Level.FINE, "Exception in file " + objFileName, ex);  // NOI18N
        } finally {
            if (dump != null) {
                dump.dispose();
            }
        }
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/cnd.dwarfdump/src/org/netbeans/modules/cnd/dwarfdump/trace/TraceDwarf.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.cnd.dwarfdump.trace;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.logging.Level;
import org.netbeans.modules.cnd.dwarfdump.CompilationUnitInterface;
import org.netbeans.modules.cnd.dwarfdump.Dwarf;
import org.netbeans.modules.cnd.dwarfdump.Dwarf.CompilationUnitIterator;
import org.netbeans.modules.cnd.dwarfdump.exception.WrongFileFormatException;


/**
 *
 * @author Sergey Grinev
 */
public class TraceDwarf {

    private TraceDwarf() {
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        String objFileName = args[0];
        Dwarf dump = null;
        try {
            Dwarf.LOG.log(Level.FINE, "TraceDwarf.");  // NOI18N
            dump = new Dwarf(objFileName);
            CompilationUnitIterator units = dump.iteratorCompilationUnits();
            int idx = 0;
            if (units.hasNext()) {
                Dwarf.LOG.log(Level.FINE, "\n**** Done. Compilation units were found"); // NOI18N
                while(units.hasNext()) {
                    CompilationUnitInterface compilationUnit = units.next();
                    Dwarf.LOG.log(Level.FINE, "{0}: {1}", new Object[]{++idx, compilationUnit.getSourceFileName()});// NOI18N
                }

            }
        } catch (FileNotFoundException ex) {
            // Skip Exception
            Dwarf.LOG.log(Level.FINE, "File not found {0}: {1}", new Object[]{objFileName, ex.getMessage()});  // NOI18N
        } catch (WrongFileFormatException ex) {
            Dwarf.LOG.log(Level.FINE, "Unsuported format of file {0}: {1}", new Object[]{objFileName, ex.getMessage()});  // NOI18N
        } catch (IOException ex) {
            Dwarf.LOG.log(Level.FINE, "Exception in file " + objFileName, ex);  // NOI18N
        } catch (Exception ex) {
            Dwarf.LOG.log(Level.FINE, "Exception in file " + objFileName, ex);  // NOI18N
        } finally {
            if (dump != null) {
                dump.dispose();
            }
        }
    }
}
